Changelog
=========

1.4.0 (2024-06-24)
------------------
* Using ``qtpy`` library instead of my own Qt5/6 mechanism
* Support for Numpy 2.0
* Extended API and docstrings
* Added argument `encoding`, defaulting to "utf-8"
* Added type hints
* Added method `get_filepath()`

1.3.0 (2023-02-27)
------------------
* Raise `ImportError` instead of general `Exception`

1.2.0 (2022-09-13)
------------------
* Added support for PyQt5, PyQt6, PySide2 and PySide6

1.1.0 (2021-05-13)
------------------
* Added support for `numpy.savetxt()`

1.0.0 (2020-08-11)
------------------
* First release on PyPI
